@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2014-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,20 +20,17 @@
 #include "ksieveui_export.h"
 
 #include <QUrl>
-
+#include <KSieveUi/SieveImapAccountSettings>
 #include <QWidget>
 #include <QMap>
 
 class QTreeWidgetItem;
 
-namespace KManageSieve
-{
+namespace KManageSieve {
 class SieveJob;
 }
 
-namespace KSieveUi
-{
-class SieveImapAccountSettings;
+namespace KSieveUi {
 class ManageSieveTreeView;
 class ManageSieveWidgetPrivate;
 class ParseUserScriptJob;
@@ -46,6 +43,15 @@ public:
         NormalEditorMode = 0,
         Kep14EditorMode
     };
+
+    struct ScriptInfo
+    {
+        QUrl currentUrl;
+        QStringList currentCapabilities;
+        KSieveUi::SieveImapAccountSettings sieveImapAccountSettings;
+        QStringList scriptList;
+    };
+
     explicit ManageSieveWidget(QWidget *parent = nullptr);
     ~ManageSieveWidget();
 
@@ -54,8 +60,8 @@ public:
 
 Q_SIGNALS:
     void updateButtons(QTreeWidgetItem *item);
-    void newScript(const QUrl &u, const QStringList &currentCapabilities, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings);
-    void editScript(const QUrl &url, const QStringList &currentCapabilities, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings);
+    void newScript(const ScriptInfo &info);
+    void editScript(const ScriptInfo &info);
     void scriptDeleted(const QUrl &u);
     void serverSieveFound(bool imapFound);
     void scriptRenamed(const QUrl &oldUrl, const QUrl &newUrl);
@@ -95,8 +101,10 @@ private:
         SIEVE_SERVER_ERROR = Qt::UserRole + 1,
         SIEVE_SERVER_CAPABILITIES = Qt::UserRole + 2,
         SIEVE_SERVER_MODE = Qt::UserRole + 3,
-        SIEVE_SERVER_IMAP_SETTINGS = Qt::UserRole + 4
+        SIEVE_SERVER_IMAP_SETTINGS = Qt::UserRole + 4,
+        SIEVE_SERVER_LIST_SCRIPT = Qt::UserRole + 5
     };
+    bool canAddNewScript(QTreeWidgetItem *item, bool jobsListIsEmpty);
     bool serverHasError(QTreeWidgetItem *item) const;
     void killAllJobs();
     void clear();
